<?php

/**
 * This file is part of the OpenPNE package.
 * (c) OpenPNE Project (http://www.openpne.jp/)
 *
 * For the full copyright and license information, please view the LICENSE
 * file and the NOTICE file that were distributed with this source code.
 */

/**
 * opSecurityConfigHandler
 *
 * @package    OpenPNE
 * @subpackage config
 * @author     Kousuke Ebihara <ebihara@tejimaya.com>
 */
class opSecurityConfigHandler extends sfSecurityConfigHandler
{
  const BOTH_REPLACEMENT = '#######BOTH#######';

  public function execute($configFiles)
  {
    $configFiles = self::filterOpenPNEPluginConfig($configFiles);

    // parse the yaml
    $config = self::getConfiguration($configFiles);

    // compile data (from sfSecurityConfigHandler)
    $retval = sprintf("<?php\n".
                      "// auto-generated by opSecurityConfigHandler\n".
                      "// date: %s\n\$this->security = %s;\n",
                      date('Y/m/d H:i:s'), var_export($config, true));

    $retval = str_replace(var_export(self::BOTH_REPLACEMENT, true), '$this->getUser()->isAuthenticated()', $retval);

    return $retval;
  }

  static public function getConfiguration(array $configFiles)
  {
    $config = parent::getConfiguration($configFiles);

    foreach ($config as $k => $v)
    {
      if (isset($v['is_secure']) && 'both' === $v['is_secure'])
      {
        $config[$k]['is_secure'] = self::BOTH_REPLACEMENT;
      }
    }

    return $config;
  }

  static protected function filterOpenPNEPluginConfig($configFiles)
  {
    // A security.yml in the plugin root configuration directory should be ignored
    $regexp = '/'.preg_quote(sfConfig::get('sf_plugins_dir').DIRECTORY_SEPARATOR, '/')
            . 'op.+Plugin'.preg_quote(DIRECTORY_SEPARATOR.'config'.DIRECTORY_SEPARATOR.'security.yml', '/').'/';

    foreach ($configFiles as $k => $v)
    {
      if (preg_match($regexp, $v))
      {
        unset($configFiles[$k]);
      }
    }

    return $configFiles;
  }
}
